/**
 * This software is contributed or developed by KYOCERA Corporation.
 * (C) 2019 KYOCERA Corporation
 */

#include "base/android/afp_config_util.h"

#include "jni/AfpConfigUtil_jni.h"

namespace base {
namespace android {

using namespace std;

AfpConfigUtil::AfpConfigUtil() {
  map_["color_picker_scroll"] = 1;
  map_["picker_softkey"] = 0;
  map_["webview_readout"] = 0;
  map_["webview_ime"] = 0;
  map_["custom_min_focusring"] = 0;
  map_["custom_min_focusring_value"] = 1;
  map_["select_popup_theme"] = 0;
  map_["focusring_important"] = 0;
  map_["ime_save_cursor"] = 0;
}

AfpConfigUtil::~AfpConfigUtil() {}

void JNI_AfpConfigUtil_SetConfigValues(JNIEnv* env,
    const JavaParamRef<jobject>&,
    const JavaParamRef<jobjectArray>& values) {
      std::vector<std::string> j_values;
      if (values != nullptr) {
        AppendJavaStringArrayToStringVector(env, values, &j_values);
        AfpConfigUtil::getInstance()->SetConfigValueList(j_values);
      }
    }

jboolean JNI_AfpConfigUtil_GetConfigBooleanValue(JNIEnv* env,
    const JavaParamRef<jobject>&,
    const JavaParamRef<jstring>& key) {
  int value = AfpConfigUtil::getInstance()->GetConfigValue(ConvertJavaStringToUTF8(env, key));
  return value == 0 ? false : true;
}

jint JNI_AfpConfigUtil_GetConfigIntValue(JNIEnv* env,
    const JavaParamRef<jobject>&,
    const JavaParamRef<jstring>& key) {

  return AfpConfigUtil::getInstance()->GetConfigValue(ConvertJavaStringToUTF8(env, key));
}

int AfpConfigUtil::GetConfigValue(string key) {
  if (map_.count(key) > 0) {
    std::map<string, int>::iterator itr = map_.find(key);
    return itr->second;
  }
  return 0;
}

void AfpConfigUtil::SetConfigValueList(vector<string> values) {
  for (unsigned int i=0; i < values.size(); ++i) {
    string key;
    int value = 0;
    SplitConfigValue(values[i],key,value);
    map_.erase(key);
    map_.insert(make_pair(key, value));
  }
}

void AfpConfigUtil::SplitConfigValue(string value_text, string& key, int& value) {
  string::size_type pos = value_text.find("=");
  if(pos == string::npos) {
    key = value_text.substr(0);
  } else {
    key = value_text.substr(0, pos);
    value = atoi(value_text.substr(pos + 1).c_str());
  }
}

} // namespace android
} // namespace base