// Copyright 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
/**
 * This software is contributed or developed by KYOCERA Corporation.
 * (C) 2019 KYOCERA Corporation
 */

package org.chromium.components.embedder_support.delegate;

import android.content.Context;
import android.graphics.Color;
import android.graphics.drawable.GradientDrawable;
import android.graphics.drawable.LayerDrawable;
import android.support.v4.view.MarginLayoutParamsCompat;
import android.text.TextUtils;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AbsListView;
import android.widget.ArrayAdapter;
import android.widget.BaseAdapter;
import android.widget.LinearLayout;

/**
 * The adapter used to populate ColorPickerSimple.
 */
public class ColorSuggestionListAdapter extends ArrayAdapter<ColorSuggestion> {
    private Context mContext;
    private ColorSuggestion[] mSuggestions;

    ColorSuggestionListAdapter(Context context, int resource, ColorSuggestion[] suggestions) {
        super(context, resource, suggestions);
        mContext = context;
        mSuggestions = suggestions;
    }

    /**
     * Sets up the color button to represent a color suggestion.
     *
     * @param button The button view to set up.
     * @param index The index of the suggestion in mSuggestions.
     */
    private void setUpColorButton(View button, int index) {
        if (index >= mSuggestions.length) {
            button.setTag(null);
            button.setContentDescription(null);
            button.setVisibility(View.INVISIBLE);
            return;
        }
        button.setTag(mSuggestions[index]);
        button.setVisibility(View.VISIBLE);
        ColorSuggestion suggestion = mSuggestions[index];
        LayerDrawable layers = (LayerDrawable) button.getBackground();
        GradientDrawable swatch =
                (GradientDrawable) layers.findDrawableByLayerId(R.id.color_button_swatch);
        swatch.setColor(suggestion.mColor);
        String description = suggestion.mLabel;
        if (TextUtils.isEmpty(description)) {
            description = String.format("#%06X", (0xFFFFFF & suggestion.mColor));
        }
        button.setContentDescription(description);
    }

    @Override
    public View getView(int position, View convertView, ViewGroup parent) {
        LinearLayout layout;
        if (convertView instanceof LinearLayout) {
            layout = (LinearLayout) convertView;
        } else {
            layout = new LinearLayout(mContext);
            layout.setLayoutParams(new AbsListView.LayoutParams(
                    AbsListView.LayoutParams.MATCH_PARENT, AbsListView.LayoutParams.WRAP_CONTENT));
            layout.setOrientation(LinearLayout.HORIZONTAL);
            layout.setPadding(5, 5, 5, 5);
            int buttonHeight =
                    mContext.getResources().getDimensionPixelOffset(R.dimen.color_button_height);
            View button = new View(mContext);
            LinearLayout.LayoutParams layoutParams =
                    new LinearLayout.LayoutParams(AbsListView.LayoutParams.MATCH_PARENT, buttonHeight, 1f);
            button.setLayoutParams(layoutParams);
            button.setBackgroundResource(R.drawable.color_button_background);
            layout.addView(button);
        }
        setUpColorButton(layout.getChildAt(0), position);
        return layout;
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @Override
    public ColorSuggestion getItem(int position) {
        return mSuggestions[position];
    }

    @Override
    public int getCount() {
        return mSuggestions.length;
    }
}
