// Copyright 2014 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
/**
 * This software is contributed or developed by KYOCERA Corporation.
 * (C) 2019 KYOCERA Corporation
 */

package org.chromium.content.browser.picker;

import android.app.DatePickerDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.os.Build;
import android.view.KeyEvent;
import android.widget.DatePicker;

import org.chromium.base.AfpConfigUtil;
import org.chromium.base.AfpUiInterfaceWrapper;

/**
 * The behavior of the DatePickerDialog changed after JellyBean so it now calls
 * OndateSetListener.onDateSet() even when the dialog is dismissed (e.g. back button, tap
 * outside). This class will call the listener instead of the DatePickerDialog only when the
 * BUTTON_POSITIVE has been clicked.
 */
class DatePickerDialogCompat extends DatePickerDialog {
    private final OnDateSetListener mCallBack;
    private int mConfigValueSoftkey;

    public DatePickerDialogCompat(Context context,
            OnDateSetListener callBack,
            int year,
            int monthOfYear,
            int dayOfMonth) {
        super(context, callBack, year, monthOfYear, dayOfMonth);

        mCallBack = callBack;
        mConfigValueSoftkey = AfpConfigUtil.getInstance().getConfigIntValue(AfpConfigUtil.KEY_PICKER_SOFTKEY);
        if((mConfigValueSoftkey == 2)) {
            AfpUiInterfaceWrapper wrapper = new AfpUiInterfaceWrapper(context);
            wrapper.setDialogSoftkey(this, "webview_softkey_done", AfpUiInterfaceWrapper.LOCAL_RES_ID_NONE, AfpUiInterfaceWrapper.INDEX_CSK);
        }
    }

    /**
     * The superclass DatePickerDialog has null for OnDateSetListener so we need to call the
     * listener manually.
     */
    @Override
    public void onClick(DialogInterface dialog, int which) {
        if (which == BUTTON_POSITIVE && mCallBack != null && mConfigValueSoftkey <= 1) {
            DatePicker datePicker = getDatePicker();
            datePicker.clearFocus();
            mCallBack.onDateSet(datePicker, datePicker.getYear(),
                    datePicker.getMonth(), datePicker.getDayOfMonth());
        }
    }

    @Override
    public boolean dispatchKeyEvent(KeyEvent event) {
        final int keyCode = event.getKeyCode();
        switch (keyCode) {
            case KeyEvent.KEYCODE_DPAD_CENTER:
            case KeyEvent.KEYCODE_ENTER:
                if (event.getAction() == KeyEvent.ACTION_UP) {
                    if (mCallBack != null && !(mConfigValueSoftkey <= 1)) {
                        DatePicker datePicker = getDatePicker();
                        datePicker.clearFocus();
                        mCallBack.onDateSet(datePicker, datePicker.getYear(),
                                datePicker.getMonth(), datePicker.getDayOfMonth());
                        dismiss();
                        return true;
                    }
                }
        }
        return super.dispatchKeyEvent(event);
    }
}
