/**
 * This software is contributed or developed by KYOCERA Corporation.
 * (C) 2019 KYOCERA Corporation
 */

package org.chromium.content.browser.picker;

import android.app.TimePickerDialog;
import android.app.TimePickerDialog.OnTimeSetListener;
import android.content.Context;
import android.content.DialogInterface;
import android.view.KeyEvent;
import android.widget.TimePicker;

import org.chromium.base.AfpConfigUtil;
import org.chromium.base.AfpUiInterfaceWrapper;

class TimePickerDialogCompat extends TimePickerDialog {
    private final OnTimeSetListener mCallBack;
    private TimePicker mTimePicker;
    private int mInitialHourOfDay;
    private int mInitialMinute;
    private int mConfigValueSoftkey;

    public TimePickerDialogCompat(Context context,
                            OnTimeSetListener callBack,
                            int hourOfDay, int minute, boolean is24HourView) {
        super(context, 0, callBack, hourOfDay, minute, is24HourView);

        mCallBack = callBack;
        mInitialHourOfDay = hourOfDay;
        mInitialMinute = minute;
        mConfigValueSoftkey = AfpConfigUtil.getInstance().getConfigIntValue(AfpConfigUtil.KEY_PICKER_SOFTKEY);
        if((mConfigValueSoftkey == 2)) {
            AfpUiInterfaceWrapper wrapper = new AfpUiInterfaceWrapper(context);
            wrapper.setDialogSoftkey(this, "webview_softkey_done", AfpUiInterfaceWrapper.LOCAL_RES_ID_NONE, AfpUiInterfaceWrapper.INDEX_CSK);
        }
    }

    @Override
    public void onTimeChanged(TimePicker view, int hourOfDay, int minute) {
        super.onTimeChanged(view, hourOfDay, minute);
        if (mTimePicker == null) {
            mTimePicker = view;
        }
    }

    @Override
    public boolean dispatchKeyEvent(KeyEvent event) {
        final int keyCode = event.getKeyCode();
        switch (keyCode) {
            case KeyEvent.KEYCODE_DPAD_CENTER:
            case KeyEvent.KEYCODE_ENTER:
                if (event.getAction() == KeyEvent.ACTION_UP) {
                    if (mCallBack != null && !(mConfigValueSoftkey <= 1)) {
                        if (mTimePicker != null) {
                            mTimePicker.clearFocus();
                            mCallBack.onTimeSet(mTimePicker, mTimePicker.getCurrentHour(),
                                    mTimePicker.getCurrentMinute());
                        } else {
                            mCallBack.onTimeSet(null, mInitialHourOfDay,
                                    mInitialMinute);
                        }
                        dismiss();
                        return true;
                    }
                }
        }
        return super.dispatchKeyEvent(event);
    }
}
